You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@trafficcontrol.apache.org by ro...@apache.org on 2018/05/08 19:19:12 UTC

[incubator-trafficcontrol] branch master updated: prevents failure of ssl files and processing of records parameters in remap

This is an automated email from the ASF dual-hosted git repository.

rob pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-trafficcontrol.git


The following commit(s) were added to refs/heads/master by this push:
     new ad102f3  prevents failure of ssl files and processing of records parameters in remap
ad102f3 is described below

commit ad102f35f046ab63fc84b61f8481f7e5e056777a
Author: Derek Gelinas <mr...@gmail.com>
AuthorDate: Tue May 8 15:13:22 2018 -0400

    prevents failure of ssl files and processing of records parameters in remap
---
 traffic_ops/bin/traffic_ops_ort.pl | 7 ++-----
 1 file changed, 2 insertions(+), 5 deletions(-)

diff --git a/traffic_ops/bin/traffic_ops_ort.pl b/traffic_ops/bin/traffic_ops_ort.pl
index f0a9af3..54b9d0e 100755
--- a/traffic_ops/bin/traffic_ops_ort.pl
+++ b/traffic_ops/bin/traffic_ops_ort.pl
@@ -1292,8 +1292,9 @@ sub check_plugins {
 					{
 						($plugin_config_file) = split( /\s+/, $plugin_config_file);
 
 						# Skip parameters that start with '-', since those are probabably parameters, not config files.
 						last if $plugin_config_file =~ m/^-/; # Exit subblock.
+						last if $plugin_config_file =~ m/^proxy.config./;
 
 						( my @parts ) = split( /\//, $plugin_config_file );
 						$plugin_config_file = $parts[$#parts];
@@ -2564,10 +2565,6 @@ sub set_uri {
 		$URI = $cfg_file_tracker->{$filename}->{'url'};
 		( $log_level >> $DEBUG ) && print "DEBUG Setting external download URL.\n";
 	}
-	else {
-		( $log_level >> $ERROR ) && print "ERROR Configuration File API not found!  Please upgrade to Traffic Ops 2.2.  Unable to continue.\n";
-		exit 1;
-	}
 
 	return if (!defined($cfg_file_tracker->{$filename}->{'fname-in-TO'}));
 
@@ -1292,8 +1292,9 @@ sub check_plugins {
 						($plugin_config_file) = split( /\s+/, $plugin_config_file);
 
-						# Skip parameters that start with '-', since those are probabably parameters, not config files.
+						# Skip parameters that start with '-' or 'proxy.config.', since those are probabably parameters, not config files.
 						last if $plugin_config_file =~ m/^-/; # Exit subblock.

-- 
To stop receiving notification emails like this one, please contact
rob@apache.org.